# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: chaukas/spec/client/v1/client.proto
# Protobuf Python Version: 6.33.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    0,
    '',
    'chaukas/spec/client/v1/client.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from chaukas.spec.common.v1 import events_pb2 as chaukas_dot_spec_dot_common_dot_v1_dot_events__pb2
from chaukas.spec.common.v1 import query_pb2 as chaukas_dot_spec_dot_common_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#chaukas/spec/client/v1/client.proto\x12\x16\x63haukas.spec.client.v1\x1a#chaukas/spec/common/v1/events.proto\x1a\"chaukas/spec/common/v1/query.proto\"\x10\n\x0eHealthzRequest\"\x11\n\x0fHealthzResponse\"\x18\n\x16GetCapabilitiesRequest\"c\n\x17GetCapabilitiesResponse\x12H\n\x0c\x63\x61pabilities\x18\x01 \x01(\x0b\x32$.chaukas.spec.common.v1.CapabilitiesR\x0c\x63\x61pabilities\"I\n\x12IngestEventRequest\x12\x33\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1d.chaukas.spec.common.v1.EventR\x05\x65vent\"\x15\n\x13IngestEventResponse\"^\n\x17IngestEventBatchRequest\x12\x43\n\x0b\x65vent_batch\x18\x01 \x01(\x0b\x32\".chaukas.spec.common.v1.EventBatchR\neventBatch\"\x1a\n\x18IngestEventBatchResponse\"P\n\x12QueryEventsRequest\x12:\n\x05query\x18\x01 \x01(\x0b\x32$.chaukas.spec.common.v1.QueryRequestR\x05query\"X\n\x13QueryEventsResponse\x12\x41\n\x08response\x18\x01 \x01(\x0b\x32%.chaukas.spec.common.v1.QueryResponseR\x08response2\xad\x04\n\x14\x43haukasClientService\x12Z\n\x07Healthz\x12&.chaukas.spec.client.v1.HealthzRequest\x1a\'.chaukas.spec.client.v1.HealthzResponse\x12r\n\x0fGetCapabilities\x12..chaukas.spec.client.v1.GetCapabilitiesRequest\x1a/.chaukas.spec.client.v1.GetCapabilitiesResponse\x12\x66\n\x0bIngestEvent\x12*.chaukas.spec.client.v1.IngestEventRequest\x1a+.chaukas.spec.client.v1.IngestEventResponse\x12u\n\x10IngestEventBatch\x12/.chaukas.spec.client.v1.IngestEventBatchRequest\x1a\x30.chaukas.spec.client.v1.IngestEventBatchResponse\x12\x66\n\x0bQueryEvents\x12*.chaukas.spec.client.v1.QueryEventsRequest\x1a+.chaukas.spec.client.v1.QueryEventsResponseB=Z;github.com/chaukasai/chaukas-spec/chaukas/spec/client/v1;v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'chaukas.spec.client.v1.client_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/chaukasai/chaukas-spec/chaukas/spec/client/v1;v1'
  _globals['_HEALTHZREQUEST']._serialized_start=136
  _globals['_HEALTHZREQUEST']._serialized_end=152
  _globals['_HEALTHZRESPONSE']._serialized_start=154
  _globals['_HEALTHZRESPONSE']._serialized_end=171
  _globals['_GETCAPABILITIESREQUEST']._serialized_start=173
  _globals['_GETCAPABILITIESREQUEST']._serialized_end=197
  _globals['_GETCAPABILITIESRESPONSE']._serialized_start=199
  _globals['_GETCAPABILITIESRESPONSE']._serialized_end=298
  _globals['_INGESTEVENTREQUEST']._serialized_start=300
  _globals['_INGESTEVENTREQUEST']._serialized_end=373
  _globals['_INGESTEVENTRESPONSE']._serialized_start=375
  _globals['_INGESTEVENTRESPONSE']._serialized_end=396
  _globals['_INGESTEVENTBATCHREQUEST']._serialized_start=398
  _globals['_INGESTEVENTBATCHREQUEST']._serialized_end=492
  _globals['_INGESTEVENTBATCHRESPONSE']._serialized_start=494
  _globals['_INGESTEVENTBATCHRESPONSE']._serialized_end=520
  _globals['_QUERYEVENTSREQUEST']._serialized_start=522
  _globals['_QUERYEVENTSREQUEST']._serialized_end=602
  _globals['_QUERYEVENTSRESPONSE']._serialized_start=604
  _globals['_QUERYEVENTSRESPONSE']._serialized_end=692
  _globals['_CHAUKASCLIENTSERVICE']._serialized_start=695
  _globals['_CHAUKASCLIENTSERVICE']._serialized_end=1252
# @@protoc_insertion_point(module_scope)
