# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: chaukas/spec/common/v1/events.proto
# Protobuf Python Version: 6.33.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    0,
    '',
    'chaukas/spec/common/v1/events.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#chaukas/spec/common/v1/events.proto\x12\x16\x63haukas.spec.common.v1\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"m\n\x0eMessageContent\x12\x12\n\x04role\x18\x01 \x01(\tR\x04role\x12\x12\n\x04text\x18\x02 \x01(\tR\x04text\x12\x33\n\x08metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x08metadata\"\xaf\x01\n\x08ToolCall\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x35\n\targuments\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\targuments\x12#\n\rauth_required\x18\x04 \x01(\x08R\x0c\x61uthRequired\x12#\n\rfunction_name\x18\x05 \x01(\tR\x0c\x66unctionName\"\xd3\x01\n\x0cToolResponse\x12 \n\x0ctool_call_id\x18\x01 \x01(\tR\ntoolCallId\x12/\n\x06output\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructR\x06output\x12#\n\rerror_message\x18\x03 \x01(\tR\x0c\x65rrorMessage\x12*\n\x11\x65xecution_time_ms\x18\x04 \x01(\x01R\x0f\x65xecutionTimeMs\x12\x1f\n\x0bhttp_status\x18\x05 \x01(\x05R\nhttpStatus\"\x84\x05\n\rLLMInvocation\x12\x1a\n\x08provider\x18\x01 \x01(\tR\x08provider\x12\x14\n\x05model\x18\x02 \x01(\tR\x05model\x12\x31\n\x07request\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x07request\x12\x33\n\x08response\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructR\x08response\x12#\n\rprompt_tokens\x18\x05 \x01(\x05R\x0cpromptTokens\x12+\n\x11\x63ompletion_tokens\x18\x06 \x01(\x05R\x10\x63ompletionTokens\x12!\n\x0ctotal_tokens\x18\x07 \x01(\x05R\x0btotalTokens\x12 \n\x0btemperature\x18\x08 \x01(\x01R\x0btemperature\x12\x1d\n\nmax_tokens\x18\t \x01(\x05R\tmaxTokens\x12\x13\n\x05top_p\x18\n \x01(\x01R\x04topP\x12+\n\x11\x66requency_penalty\x18\x0b \x01(\x01R\x10\x66requencyPenalty\x12)\n\x10presence_penalty\x18\x0c \x01(\x01R\x0fpresencePenalty\x12\x39\n\nstart_time\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x35\n\x08\x65nd_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTime\x12\x1f\n\x0b\x64uration_ms\x18\x0f \x01(\x01R\ndurationMs\x12#\n\rfinish_reason\x18\x10 \x01(\tR\x0c\x66inishReason\"\x80\x01\n\x0ePolicyDecision\x12\x1b\n\tpolicy_id\x18\x01 \x01(\tR\x08policyId\x12\x18\n\x07outcome\x18\x02 \x01(\tR\x07outcome\x12\x19\n\x08rule_ids\x18\x03 \x03(\tR\x07ruleIds\x12\x1c\n\trationale\x18\x04 \x01(\tR\trationale\"\x93\x01\n\nDataAccess\x12\x1e\n\ndatasource\x18\x01 \x01(\tR\ndatasource\x12!\n\x0c\x64ocument_ids\x18\x02 \x03(\tR\x0b\x64ocumentIds\x12\x1b\n\tchunk_ids\x18\x03 \x03(\tR\x08\x63hunkIds\x12%\n\x0epii_categories\x18\x04 \x03(\tR\rpiiCategories\"X\n\rRedactionInfo\x12\x16\n\x06\x66ields\x18\x01 \x03(\tR\x06\x66ields\x12\x16\n\x06method\x18\x02 \x01(\tR\x06method\x12\x17\n\x07salt_id\x18\x03 \x01(\tR\x06saltId\"`\n\tRetryInfo\x12\x18\n\x07\x61ttempt\x18\x01 \x01(\x05R\x07\x61ttempt\x12\x1a\n\x08strategy\x18\x02 \x01(\tR\x08strategy\x12\x1d\n\nbackoff_ms\x18\x03 \x01(\x05R\tbackoffMs\"\xb2\x01\n\x12PerformanceMetrics\x12\x1f\n\x0b\x63pu_percent\x18\x01 \x01(\x01R\ncpuPercent\x12\x1b\n\tmemory_mb\x18\x02 \x01(\x01R\x08memoryMb\x12\x1f\n\x0b\x64uration_ms\x18\x03 \x01(\x01R\ndurationMs\x12\x1e\n\nthroughput\x18\x04 \x01(\x01R\nthroughput\x12\x1d\n\nlatency_ms\x18\x05 \x01(\x01R\tlatencyMs\"\xbf\x01\n\x15InfrastructureMetrics\x12#\n\rresource_type\x18\x01 \x01(\tR\x0cresourceType\x12\x31\n\x07metrics\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructR\x07metrics\x12\x12\n\x04host\x18\x03 \x01(\tR\x04host\x12\x1d\n\nprocess_id\x18\x04 \x01(\x05R\tprocessId\x12\x1b\n\tthread_id\x18\x05 \x01(\tR\x08threadId\"\x8d\x03\n\x0b\x43ostDetails\x12\x1a\n\x08provider\x18\x01 \x01(\tR\x08provider\x12\x18\n\x07service\x18\x02 \x01(\tR\x07service\x12!\n\x0cinput_tokens\x18\x03 \x01(\x05R\x0binputTokens\x12#\n\routput_tokens\x18\x04 \x01(\x05R\x0coutputTokens\x12!\n\x0ctotal_tokens\x18\x05 \x01(\x05R\x0btotalTokens\x12\x1d\n\ninput_cost\x18\x06 \x01(\x01R\tinputCost\x12\x1f\n\x0boutput_cost\x18\x07 \x01(\x01R\noutputCost\x12\x1d\n\ntotal_cost\x18\x08 \x01(\x01R\ttotalCost\x12\x1a\n\x08\x63urrency\x18\t \x01(\tR\x08\x63urrency\x12/\n\x14input_rate_per_token\x18\n \x01(\x01R\x11inputRatePerToken\x12\x31\n\x15output_rate_per_token\x18\x0b \x01(\x01R\x12outputRatePerToken\"\x95\x02\n\x0c\x41gentHandoff\x12\"\n\rfrom_agent_id\x18\x01 \x01(\tR\x0b\x66romAgentId\x12&\n\x0f\x66rom_agent_name\x18\x02 \x01(\tR\rfromAgentName\x12\x1e\n\x0bto_agent_id\x18\x03 \x01(\tR\ttoAgentId\x12\"\n\rto_agent_name\x18\x04 \x01(\tR\x0btoAgentName\x12:\n\x0chandoff_data\x18\x05 \x01(\x0b\x32\x17.google.protobuf.StructR\x0bhandoffData\x12\x16\n\x06reason\x18\x06 \x01(\tR\x06reason\x12!\n\x0chandoff_type\x18\x07 \x01(\tR\x0bhandoffType\"\xbe\x02\n\x07MCPCall\x12\x1f\n\x0bserver_name\x18\x01 \x01(\tR\nserverName\x12\x1d\n\nserver_url\x18\x02 \x01(\tR\tserverUrl\x12\x1c\n\toperation\x18\x03 \x01(\tR\toperation\x12\x16\n\x06method\x18\x04 \x01(\tR\x06method\x12\x31\n\x07request\x18\x05 \x01(\x0b\x32\x17.google.protobuf.StructR\x07request\x12\x33\n\x08response\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructR\x08response\x12)\n\x10protocol_version\x18\x07 \x01(\tR\x0fprotocolVersion\x12*\n\x11\x65xecution_time_ms\x18\x08 \x01(\x01R\x0f\x65xecutionTimeMs\"\xbb\x01\n\tErrorInfo\x12#\n\rerror_message\x18\x01 \x01(\tR\x0c\x65rrorMessage\x12\x1d\n\nerror_code\x18\x02 \x01(\tR\terrorCode\x12\x1f\n\x0bstack_trace\x18\x03 \x01(\tR\nstackTrace\x12 \n\x0brecoverable\x18\x04 \x01(\x08R\x0brecoverable\x12\'\n\x0frecovery_action\x18\x05 \x01(\tR\x0erecoveryAction\"\xed\x0f\n\x05\x45vent\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\tR\x07\x65ventId\x12\x1b\n\ttenant_id\x18\x02 \x01(\tR\x08tenantId\x12\x1d\n\nproject_id\x18\x03 \x01(\tR\tprojectId\x12\x1d\n\nsession_id\x18\x04 \x01(\tR\tsessionId\x12\x17\n\x07span_id\x18\x05 \x01(\tR\x06spanId\x12$\n\x0eparent_span_id\x18\x06 \x01(\tR\x0cparentSpanId\x12\x35\n\x04type\x18\x07 \x01(\x0e\x32!.chaukas.spec.common.v1.EventTypeR\x04type\x12<\n\x08severity\x18\x08 \x01(\x0e\x32 .chaukas.spec.common.v1.SeverityR\x08severity\x12;\n\x06status\x18\t \x01(\x0e\x32#.chaukas.spec.common.v1.EventStatusR\x06status\x12\x36\n\x06\x61uthor\x18\n \x01(\x0e\x32\x1e.chaukas.spec.common.v1.AuthorR\x06\x61uthor\x12\x38\n\ttimestamp\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x19\n\x08\x61gent_id\x18\x0c \x01(\tR\x07\x61gentId\x12\x1d\n\nagent_name\x18\r \x01(\tR\tagentName\x12#\n\rinvocation_id\x18\x0e \x01(\tR\x0cinvocationId\x12\x1f\n\x0bresponse_id\x18\x0f \x01(\tR\nresponseId\x12\x1d\n\nis_partial\x18\x10 \x01(\x08R\tisPartial\x12\x19\n\x08is_final\x18\x11 \x01(\x08R\x07isFinal\x12\x1b\n\thash_prev\x18\x12 \x01(\tR\x08hashPrev\x12!\n\x0c\x63ontent_hash\x18\x13 \x01(\tR\x0b\x63ontentHash\x12\"\n\rworm_proof_id\x18\x14 \x01(\tR\x0bwormProofId\x12\x16\n\x06\x62ranch\x18\x15 \x01(\tR\x06\x62ranch\x12\x12\n\x04tags\x18\x16 \x03(\tR\x04tags\x12\x19\n\x08trace_id\x18\x17 \x01(\tR\x07traceId\x12\x42\n\x07message\x18\x1e \x01(\x0b\x32&.chaukas.spec.common.v1.MessageContentH\x00R\x07message\x12?\n\ttool_call\x18\x1f \x01(\x0b\x32 .chaukas.spec.common.v1.ToolCallH\x00R\x08toolCall\x12K\n\rtool_response\x18  \x01(\x0b\x32$.chaukas.spec.common.v1.ToolResponseH\x00R\x0ctoolResponse\x12N\n\x0ellm_invocation\x18! \x01(\x0b\x32%.chaukas.spec.common.v1.LLMInvocationH\x00R\rllmInvocation\x12@\n\x06policy\x18\" \x01(\x0b\x32&.chaukas.spec.common.v1.PolicyDecisionH\x00R\x06policy\x12\x45\n\x0b\x64\x61ta_access\x18# \x01(\x0b\x32\".chaukas.spec.common.v1.DataAccessH\x00R\ndataAccess\x12<\n\x0cstate_update\x18$ \x01(\x0b\x32\x17.google.protobuf.StructH\x00R\x0bstateUpdate\x12\x39\n\x05\x65rror\x18% \x01(\x0b\x32!.chaukas.spec.common.v1.ErrorInfoH\x00R\x05\x65rror\x12K\n\ragent_handoff\x18& \x01(\x0b\x32$.chaukas.spec.common.v1.AgentHandoffH\x00R\x0c\x61gentHandoff\x12<\n\x08mcp_call\x18\' \x01(\x0b\x32\x1f.chaukas.spec.common.v1.MCPCallH\x00R\x07mcpCall\x12\x37\n\x05retry\x18< \x01(\x0b\x32!.chaukas.spec.common.v1.RetryInfoR\x05retry\x12\x43\n\tredaction\x18= \x01(\x0b\x32%.chaukas.spec.common.v1.RedactionInfoR\tredaction\x12%\n\x0epii_categories\x18> \x03(\tR\rpiiCategories\x12L\n\x0bperformance\x18\x46 \x01(\x0b\x32*.chaukas.spec.common.v1.PerformanceMetricsR\x0bperformance\x12U\n\x0einfrastructure\x18G \x01(\x0b\x32-.chaukas.spec.common.v1.InfrastructureMetricsR\x0einfrastructure\x12\x37\n\x04\x63ost\x18H \x01(\x0b\x32#.chaukas.spec.common.v1.CostDetailsR\x04\x63ost\x12\x33\n\x08metadata\x18Z \x01(\x0b\x32\x17.google.protobuf.StructR\x08metadata\x12\x34\n\nextensions\x18\x63 \x03(\x0b\x32\x14.google.protobuf.AnyR\nextensionsB\t\n\x07\x63ontent\"\xbb\x02\n\nEventBatch\x12\x19\n\x08\x62\x61tch_id\x18\x01 \x01(\tR\x07\x62\x61tchId\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x35\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x1d.chaukas.spec.common.v1.EventR\x06\x65vents\x12\x33\n\x08metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructR\x08metadata\x12\x1d\n\ntotal_cost\x18\n \x01(\x01R\ttotalCost\x12!\n\x0ctotal_tokens\x18\x0b \x01(\x05R\x0btotalTokens\x12*\n\x11total_duration_ms\x18\x0c \x01(\x01R\x0ftotalDurationMs*\xd5\x04\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x45VENT_TYPE_SESSION_START\x10\x01\x12\x1a\n\x16\x45VENT_TYPE_SESSION_END\x10\x02\x12\x1a\n\x16\x45VENT_TYPE_AGENT_START\x10\n\x12\x18\n\x14\x45VENT_TYPE_AGENT_END\x10\x0b\x12\x1c\n\x18\x45VENT_TYPE_AGENT_HANDOFF\x10\x0c\x12%\n!EVENT_TYPE_MODEL_INVOCATION_START\x10\x14\x12#\n\x1f\x45VENT_TYPE_MODEL_INVOCATION_END\x10\x15\x12\x1e\n\x1a\x45VENT_TYPE_TOOL_CALL_START\x10\x16\x12\x1c\n\x18\x45VENT_TYPE_TOOL_CALL_END\x10\x17\x12\x1d\n\x19\x45VENT_TYPE_MCP_CALL_START\x10\x18\x12\x1b\n\x17\x45VENT_TYPE_MCP_CALL_END\x10\x19\x12\x1d\n\x19\x45VENT_TYPE_INPUT_RECEIVED\x10\x1e\x12\x1d\n\x19\x45VENT_TYPE_OUTPUT_EMITTED\x10\x1f\x12\x14\n\x10\x45VENT_TYPE_ERROR\x10(\x12\x14\n\x10\x45VENT_TYPE_RETRY\x10)\x12\x1e\n\x1a\x45VENT_TYPE_POLICY_DECISION\x10<\x12\x1a\n\x16\x45VENT_TYPE_DATA_ACCESS\x10=\x12\x1b\n\x17\x45VENT_TYPE_STATE_UPDATE\x10>\x12\x15\n\x11\x45VENT_TYPE_SYSTEM\x10?*\xb4\x01\n\x0b\x45ventStatus\x12\x1c\n\x18\x45VENT_STATUS_UNSPECIFIED\x10\x00\x12\x18\n\x14\x45VENT_STATUS_STARTED\x10\x01\x12\x1c\n\x18\x45VENT_STATUS_IN_PROGRESS\x10\x02\x12\x1a\n\x16\x45VENT_STATUS_COMPLETED\x10\x03\x12\x17\n\x13\x45VENT_STATUS_FAILED\x10\x04\x12\x1a\n\x16\x45VENT_STATUS_CANCELLED\x10\x05*r\n\x08Severity\x12\x18\n\x14SEVERITY_UNSPECIFIED\x10\x00\x12\x12\n\x0eSEVERITY_DEBUG\x10\x01\x12\x11\n\rSEVERITY_INFO\x10\x02\x12\x11\n\rSEVERITY_WARN\x10\x03\x12\x12\n\x0eSEVERITY_ERROR\x10\x04*w\n\x06\x41uthor\x12\x16\n\x12\x41UTHOR_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x41UTHOR_USER\x10\x01\x12\x10\n\x0c\x41UTHOR_AGENT\x10\x02\x12\x0f\n\x0b\x41UTHOR_TOOL\x10\x03\x12\x11\n\rAUTHOR_SYSTEM\x10\x04\x12\x0e\n\nAUTHOR_LLM\x10\x05\x42=Z;github.com/chaukasai/chaukas-spec/chaukas/spec/common/v1;v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'chaukas.spec.common.v1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/chaukasai/chaukas-spec/chaukas/spec/common/v1;v1'
  _globals['_EVENTTYPE']._serialized_start=5689
  _globals['_EVENTTYPE']._serialized_end=6286
  _globals['_EVENTSTATUS']._serialized_start=6289
  _globals['_EVENTSTATUS']._serialized_end=6469
  _globals['_SEVERITY']._serialized_start=6471
  _globals['_SEVERITY']._serialized_end=6585
  _globals['_AUTHOR']._serialized_start=6587
  _globals['_AUTHOR']._serialized_end=6706
  _globals['_MESSAGECONTENT']._serialized_start=153
  _globals['_MESSAGECONTENT']._serialized_end=262
  _globals['_TOOLCALL']._serialized_start=265
  _globals['_TOOLCALL']._serialized_end=440
  _globals['_TOOLRESPONSE']._serialized_start=443
  _globals['_TOOLRESPONSE']._serialized_end=654
  _globals['_LLMINVOCATION']._serialized_start=657
  _globals['_LLMINVOCATION']._serialized_end=1301
  _globals['_POLICYDECISION']._serialized_start=1304
  _globals['_POLICYDECISION']._serialized_end=1432
  _globals['_DATAACCESS']._serialized_start=1435
  _globals['_DATAACCESS']._serialized_end=1582
  _globals['_REDACTIONINFO']._serialized_start=1584
  _globals['_REDACTIONINFO']._serialized_end=1672
  _globals['_RETRYINFO']._serialized_start=1674
  _globals['_RETRYINFO']._serialized_end=1770
  _globals['_PERFORMANCEMETRICS']._serialized_start=1773
  _globals['_PERFORMANCEMETRICS']._serialized_end=1951
  _globals['_INFRASTRUCTUREMETRICS']._serialized_start=1954
  _globals['_INFRASTRUCTUREMETRICS']._serialized_end=2145
  _globals['_COSTDETAILS']._serialized_start=2148
  _globals['_COSTDETAILS']._serialized_end=2545
  _globals['_AGENTHANDOFF']._serialized_start=2548
  _globals['_AGENTHANDOFF']._serialized_end=2825
  _globals['_MCPCALL']._serialized_start=2828
  _globals['_MCPCALL']._serialized_end=3146
  _globals['_ERRORINFO']._serialized_start=3149
  _globals['_ERRORINFO']._serialized_end=3336
  _globals['_EVENT']._serialized_start=3339
  _globals['_EVENT']._serialized_end=5368
  _globals['_EVENTBATCH']._serialized_start=5371
  _globals['_EVENTBATCH']._serialized_end=5686
# @@protoc_insertion_point(module_scope)
