# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: chaukas/spec/common/v1/query.proto
# Protobuf Python Version: 6.33.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    0,
    '',
    'chaukas/spec/common/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from chaukas.spec.common.v1 import events_pb2 as chaukas_dot_spec_dot_common_dot_v1_dot_events__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"chaukas/spec/common/v1/query.proto\x12\x16\x63haukas.spec.common.v1\x1a#chaukas/spec/common/v1/events.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"k\n\tTimeRange\x12\x30\n\x05start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x05start\x12,\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x03\x65nd\"\xdd\x03\n\x0bQueryFilter\x12\x1b\n\ttenant_id\x18\x01 \x01(\tR\x08tenantId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12\x1d\n\nsession_id\x18\x03 \x01(\tR\tsessionId\x12\x19\n\x08\x61gent_id\x18\x04 \x01(\tR\x07\x61gentId\x12\x17\n\x07span_id\x18\x05 \x01(\tR\x06spanId\x12\x19\n\x08trace_id\x18\x06 \x01(\tR\x07traceId\x12\x37\n\x05types\x18\n \x03(\x0e\x32!.chaukas.spec.common.v1.EventTypeR\x05types\x12?\n\x08statuses\x18\x0b \x03(\x0e\x32#.chaukas.spec.common.v1.EventStatusR\x08statuses\x12@\n\nseverities\x18\x0c \x03(\x0e\x32 .chaukas.spec.common.v1.SeverityR\nseverities\x12\x12\n\x04tags\x18\x14 \x03(\tR\x04tags\x12\x1d\n\ntext_query\x18\x15 \x01(\tR\ttextQuery\x12\x35\n\x04time\x18\x1e \x01(\x0b\x32!.chaukas.spec.common.v1.TimeRangeR\x04time\"\xce\x01\n\x0cQueryRequest\x12;\n\x06\x66ilter\x18\x01 \x01(\x0b\x32#.chaukas.spec.common.v1.QueryFilterR\x06\x66ilter\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x45\n\rorder_by_time\x18\x04 \x01(\x0e\x32!.chaukas.spec.common.v1.SortOrderR\x0borderByTime\"n\n\rQueryResponse\x12\x35\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1d.chaukas.spec.common.v1.EventR\x06\x65vents\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\x84\x02\n\x0c\x43\x61pabilities\x12%\n\x0eworm_retention\x18\x01 \x01(\x08R\rwormRetention\x12!\n\x0c\x61udit_proofs\x18\x02 \x01(\x08R\x0b\x61uditProofs\x12+\n\x11\x64istributed_query\x18\x03 \x01(\x08R\x10\x64istributedQuery\x12\x12\n\x04rbac\x18\x04 \x01(\x08R\x04rbac\x12\x10\n\x03sso\x18\x05 \x01(\x08R\x03sso\x12)\n\x10policy_decisions\x18\x06 \x01(\x08R\x0fpolicyDecisions\x12,\n\x12\x64\x61ta_access_events\x18\x07 \x01(\x08R\x10\x64\x61taAccessEvents*P\n\tSortOrder\x12\x1a\n\x16SORT_ORDER_UNSPECIFIED\x10\x00\x12\x12\n\x0eSORT_ORDER_ASC\x10\x01\x12\x13\n\x0fSORT_ORDER_DESC\x10\x02\x42=Z;github.com/chaukasai/chaukas-spec/chaukas/spec/common/v1;v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'chaukas.spec.common.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/chaukasai/chaukas-spec/chaukas/spec/common/v1;v1'
  _globals['_SORTORDER']._serialized_start=1305
  _globals['_SORTORDER']._serialized_end=1385
  _globals['_TIMERANGE']._serialized_start=132
  _globals['_TIMERANGE']._serialized_end=239
  _globals['_QUERYFILTER']._serialized_start=242
  _globals['_QUERYFILTER']._serialized_end=719
  _globals['_QUERYREQUEST']._serialized_start=722
  _globals['_QUERYREQUEST']._serialized_end=928
  _globals['_QUERYRESPONSE']._serialized_start=930
  _globals['_QUERYRESPONSE']._serialized_end=1040
  _globals['_CAPABILITIES']._serialized_start=1043
  _globals['_CAPABILITIES']._serialized_end=1303
# @@protoc_insertion_point(module_scope)
